@@ -2,7 +2,7 @@ import sys
 
 import square.main
 
-if __name__ == '__main__':
+if __name__ == '__main__':      # codecov-skip
     try:
         sys.exit(square.main.main())
     except KeyboardInterrupt:
